Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorWillian Padovani Germano <wpgermano@gmail.com>2005-04-21 23:44:52 +0400
committerWillian Padovani Germano <wpgermano@gmail.com>2005-04-21 23:44:52 +0400
commit589ce4a005ce16c5a628cd51819e20623a23c891 (patch)
tree111a9dc91ad3f1843694d47aaf8eb66c1358820d /source/blender/python/api2_2x/doc/Material.py
parentc5214c15716715cd513e1d2b61433784eb64b617 (diff)
BPython:
- based on a request by Campbell (he also provided a patch for scene.Layer) access to layers was improved a little, keeping the old method (ob.Layers is a bitmask) and adding the nicer one (ob.layers is a list of ints). Done for objects and scenes. House-cleaning: .Layer was renamed to .Layers (actually just using strncmp instead of strcmp, so both work, same done for Window.ViewLayers). - finally committing patch by Ken Hughes to let .clearScriptLinks() accept a parameter (list of strings) to clear only specified texts. - doc updates and fixes (JMS reported a problem in nmesh.transform() example code). Thanks all who contributed.
Diffstat (limited to 'source/blender/python/api2_2x/doc/Material.py')
-rw-r--r--source/blender/python/api2_2x/doc/Material.py11
1 files changed, 6 insertions, 5 deletions
diff --git a/source/blender/python/api2_2x/doc/Material.py b/source/blender/python/api2_2x/doc/Material.py
index 8997fc1b402..79d28b1162b 100644
--- a/source/blender/python/api2_2x/doc/Material.py
+++ b/source/blender/python/api2_2x/doc/Material.py
@@ -3,7 +3,7 @@
"""
The Blender.Material submodule.
-B{New}: scriptLink methods: L{Material.getScriptLinks}, ...
+B{New}: L{Material.clearScriptLinks} accepts a parameter now.
Material
========
@@ -643,11 +643,12 @@ class Material:
'event' type) or None if there are no script links at all.
"""
- def clearScriptLinks ():
+ def clearScriptLinks (links = None):
"""
- Delete all this Material's script links.
- @rtype: bool
- @return: 0 if some internal problem occurred or 1 if successful.
+ Delete script links from this Material. If no list is specified, all
+ script links are deleted.
+ @type links: list of strings
+ @param links: None (default) or a list of Blender L{Text} names.
"""
def addScriptLink (text, event):